@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.49.3'; # our $VERSION = '';
+$VERSION = '0.49.5'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1165,7 +1165,8 @@ Sim::OPT.
 =head1 DESCRIPTION
 
 Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. Some of Sim::OPT's optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (inexact Gauss-Seidel method). Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring new search spaces. Sim::OPT's morphing module (Sim::OPT::Morph) manipulates text files recognizing variables by position. The Sim::OPT::Parcoord3d module converts 2D parallel coordinates plots in Autolisp instructions for obtaining 3D plots as Autocad drawings.
-Sim::OPT's morhing and reporting modules contain several additional functions specifically targeting the ESP-r building performance simulation platform. A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use those functionalities.
+
+Sim::OPT's morphing and reporting modules contain several additional functions specifically targeting the ESP-r building performance simulation platform. A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use those functionalities.
 
 To install Sim::OPT, the command <cpanm Sim::OPT> has to be issued as a superuser. OPT can then be loaded through the command <use Sim::OPT> in a Perl repl. To ease the launch, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "examples" folder in this distribution) may be copied in a work directory and the command <opt> may be issued (not as a superuser). That command will call OPT with the settings specified in the configuration file. When launched, Sim::OPT will ask the path to that file, which must contain a suitable description of the operations to be accomplished and point to an existing simulation model.
 
@@ -1185,7 +1186,7 @@ The instance number that has to considered the basic one, corresponding to the r
 
 Where Sim::OPT may be fit for a task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overlapping subproblems; when there aren't slick tools suitable to decomposition-based, simulation-based optimization; when spending a day, or two, or three setting up a model may spare months of work.
 
-Where it may not be suited for the task? For quick shots at small explorations.
+Where it may not be suitable for the task? For quick shots at small explorations.
 
 Gian Luca Brunetti
 
